==> freecad_0.16.6712%2Bdfsg1.orig.tar.xz: FreeCAD-0.16.6712/src/Mod/Plot/resources/translations/Plot_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ro" sourcelanguage="en">
  <context>
    <name>Plot</name>
    <message>
      <location filename="InitGui.py" line="44"/>
      <source>Plot edition tools</source>
      <translation>Unelte de printare</translation>
    </message>
    <message>
      <location filename="InitGui.py" line="47"/>
      <source>Plot</source>
      <translation>Printare</translation>
    </message>
  </context>
  <context>
    <name>Plot_Axes</name>
    <message>
      <location filename="PlotGui.py" line="62"/>
      <source>Configure axes</source>
      <translation>Configurare axe</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="65"/>
      <source>Configure the axes parameters</source>
      <translation>Configurează parametrii axelor</translation>
    </message>
  </context>
  <context>
    <name>Plot_Grid</name>
    <message>
      <location filename="PlotGui.py" line="110"/>
      <source>Show/Hide grid</source>
      <translation>Afisare/Ascundere grila</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="113"/>
      <source>Show/Hide grid on selected plot</source>
      <translation>Afisare/Ascundere grila pe desenul selectat</translation>
    </message>
  </context>
  <context>
    <name>Plot_Labels</name>
    <message>
      <location filename="PlotGui.py" line="154"/>
      <source>Set labels</source>
      <translation>Seteaza etichete</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="157"/>
      <source>Set title and axes labels</source>
      <translation>Seteaza titlul si etichetele axelor</translation>
    </message>
  </context>
  <context>
    <name>Plot_Legend</name>
    <message>
      <location filename="PlotGui.py" line="137"/>
      <source>Show/Hide legend</source>
      <translation>Afisare/Ascundere legenda</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="140"/>
      <source>Show/Hide legend on selected plot</source>
      <translation>Afisare/Ascundere legenda in desenul selectat</translation>
    </message>
  </context>
  <context>
    <name>Plot_Positions</name>
    <message>
      <location filename="PlotGui.py" line="171"/>
      <source>Set positions and sizes</source>
      <translation>Seteaza poziţia si dimensiunile</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="174"/>
      <source>Set labels and legend positions and sizes</source>
      <translation>Seteaza pozitia si dimensiunile pentru etichete si legenda</translation>
    </message>
  </context>
  <context>
    <name>Plot_SaveFig</name>
    <message>
      <location filename="PlotGui.py" line="45"/>
      <source>Save plot</source>
      <translation>Salvati desenul</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="48"/>
      <source>Save the plot as an image file</source>
      <translation>Salvează schița ca un fișier imagine</translation>
    </message>
  </context>
  <context>
    <name>Plot_Series</name>
    <message>
      <location filename="PlotGui.py" line="81"/>
      <source>Configure series</source>
      <translation>Configrare serie</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="84"/>
      <source>Configure series drawing style and label</source>
      <translation>Configurarea stilului de desenare si etichetei pentru serii</translation>
    </message>
  </context>
  <context>
    <name>plot_axes</name>
    <message>
      <location filename="TaskPanel.py" line="175"/>
      <source>Configure axes</source>
      <translation>Configurare axe</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="180"/>
      <source>Active axes</source>
      <translation>Axe active</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="220"/>
      <source>Apply to all axes</source>
      <translation>Se aplica la toate axele</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="225"/>
      <source>Dimensions</source>
      <translation>Dimensiuni</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="230"/>
      <source>X axis position</source>
      <translation>Pozitia axei x</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="235"/>
      <source>Y axis position</source>
      <translation>Pozitia axei y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="205"/>
      <source>Scales</source>
      <translation>Scari</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="210"/>
      <source>X auto</source>
      <translation>X auto</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="215"/>
      <source>Y auto</source>
      <translation>Y auto</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="240"/>
      <source>Index of the active axes</source>
      <translation>Indicii axelor active</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="245"/>
      <source>Add new axes to the plot</source>
      <translation>Adauga axe noi la grafic</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="251"/>
      <source>Remove selected axes</source>
      <translation>Elimina axele selectate</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="257"/>
      <source>Check it to apply transformations to all axes</source>
      <translation>Bifati pentru a aplica transformarea tuturor axelor</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="263"/>
      <source>Left bound of axes</source>
      <translation>Marginea stanga a axelor</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="269"/>
      <source>Right bound of axes</source>
      <translation>Marginea dreapta a axelor</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="275"/>
      <source>Bottom bound of axes</source>
      <translation>Marginea de jos a axelor</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="281"/>
      <source>Top bound of axes</source>
      <translation>Marginea de sus a axelor</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="287"/>
      <source>Outward offset of X axis</source>
      <translation>Deplasare spre exterior pe axa x</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="293"/>
      <source>Outward offset of Y axis</source>
      <translation>Deplasare spre interior pe axa x</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="299"/>
      <source>X axis scale autoselection</source>
      <translation>Autoslectare scara pentru axa X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="305"/>
      <source>Y axis scale autoselection</source>
      <translation>Autoslectare scara pentru axa Y</translation>
    </message>
  </context>
  <context>
    <name>plot_console</name>
    <message>
      <location filename="Plot.py" line="43"/>
      <source>matplotlib not found, so Plot module can not be loaded</source>
      <translation>matplotlib nu a fost gait, astfel ca modulul Plot nu poate fi incarcat</translation>
    </message>
    <message>
      <location filename="InitGui.py" line="54"/>
      <source>matplotlib not found, Plot module will be disabled</source>
      <translation>matplotlib nu a fost gait, astfel ca modulul Plot va fi dezactivat</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="42"/>
      <source>Plot document must be selected in order to save it</source>
      <translation>Documentul de printat trebuie selectat pentru a-l salva</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="365"/>
      <source>Axes 0 can not be deleted</source>
      <translation>Axele 0 nu pot fi sterse</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="97"/>
      <source>The grid must be activated on top of a plot document</source>
      <translation>Grila trebuie activată pe partea de sus a graficului unui document</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="126"/>
      <source>The legend must be activated on top of a plot document</source>
      <translation>Legenda trebuie activată pe partea de sus a graficului documentului</translation>
    </message>
  </context>
  <context>
    <name>plot_labels</name>
    <message>
      <location filename="TaskPanel.py" line="133"/>
      <source>Set labels</source>
      <translation>Seteaza etichete</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="138"/>
      <source>Active axes</source>
      <translation>Axe active</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="143"/>
      <source>Title</source>
      <translation>Titlu</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="148"/>
      <source>X label</source>
      <translation>eticheta X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="153"/>
      <source>Y label</source>
      <translation>eticheta Y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="158"/>
      <source>Index of the active axes</source>
      <translation>Indicii axelor active</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="163"/>
      <source>Title (associated to active axes)</source>
      <translation>Titlu (asociat cu axa activa)</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="169"/>
      <source>Title font size</source>
      <translation>Dimensiunea font-ului pentru titlu</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="175"/>
      <source>X axis title</source>
      <translation>Titlu pentru axa X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="181"/>
      <source>X axis title font size</source>
      <translation>Dimensiunea font-ului pentru axa X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="187"/>
      <source>Y axis title</source>
      <translation>Titlu pentru axa Y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="193"/>
      <source>Y axis title font size</source>
      <translation>Dimensiunea font-ului pentru axa Y</translation>
    </message>
  </context>
  <context>
    <name>plot_positions</name>
    <message>
      <location filename="TaskPanel.py" line="121"/>
      <source>Set positions and sizes</source>
      <translation>Seteaza poziţia si dimensiunile</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="126"/>
      <source>Position</source>
      <translation type="unfinished">Position</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="132"/>
      <source>Size</source>
      <translation>Dimensiune</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="138"/>
      <source>List of modificable items</source>
      <translation>Lista obiectelor modificable</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="144"/>
      <source>X item position</source>
      <translation>Pozitia pe X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="150"/>
      <source>Y item position</source>
      <translation>Pozitia pe Y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="156"/>
      <source>Item size</source>
      <translation>Dimensiune element</translation>
    </message>
  </context>
  <context>
    <name>plot_save</name>
    <message>
      <location filename="TaskPanel.py" line="128"/>
      <source>Save figure</source>
      <translation>Salveaza figura</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="133"/>
      <source>Inches</source>
      <translation>Toli</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="139"/>
      <source>Dots per Inch</source>
      <translation>Puncte pe Tol</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="145"/>
      <source>Output image file path</source>
      <translation>Calea pentru fisierul imagine rezultat</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="151"/>
      <source>Show a file selection dialog</source>
      <translation>Prezinta dialogul de selectie a fisierelor</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="157"/>
      <source>X image size</source>
      <translation>Dimensiune imagine pe X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="163"/>
      <source>Y image size</source>
      <translation>Dimensiune imagine pe Y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="169"/>
      <source>Dots per point, with size will define output image resolution</source>
      <translation>puncte pe pixel si dimensiunea vor defini rezolutia imagini</translation>
    </message>
  </context>
  <context>
    <name>plot_series</name>
    <message>
      <location filename="TaskPanel.py" line="154"/>
      <source>No label</source>
      <translation>Fara eticheta</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="160"/>
      <source>Remove serie</source>
      <translation>Elimina serie</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="196"/>
      <source>Line style</source>
      <translation>Stilul de linie</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="172"/>
      <source>Marker</source>
      <translation>Marcator</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="149"/>
      <source>Configure series</source>
      <translation>Configrare serie</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="178"/>
      <source>List of available series</source>
      <translation>Lista seriilor disponibile</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="184"/>
      <source>Line title</source>
      <translation>Titlul liniei</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="202"/>
      <source>Marker style</source>
      <translation>Stil marcator</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="208"/>
      <source>Line width</source>
      <translation>Latimea liniei</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="214"/>
      <source>Marker size</source>
      <translation>Dimensiune marcator</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="220"/>
      <source>Line and marker color</source>
      <translation>Culoare linie si marker</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="226"/>
      <source>Removes this serie</source>
      <translation>Elimina aceasta serie</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="190"/>
      <source>If checked serie will not be considered for legend</source>
      <translation>Daca e bifat, seria nu va fi luata in considerare pentru legenda</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.1%2Bdfsg1.orig.tar.xz: FreeCAD-0.19.1/src/Mod/Plot/resources/translations/Plot_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="1.1" language="ro" sourcelanguage="en">
  <context>
    <name>Plot</name>
    <message>
      <location filename="InitGui.py" line="46"/>
      <source>Plot edition tools</source>
      <translation>Unelte de reprezentare grafică</translation>
    </message>
    <message>
      <location filename="InitGui.py" line="49"/>
      <source>Plot</source>
      <translation>Reprezentare grafică</translation>
    </message>
  </context>
  <context>
    <name>Plot_Axes</name>
    <message>
      <location filename="PlotGui.py" line="65"/>
      <source>Configure axes</source>
      <translation>Configurare axe</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="68"/>
      <source>Configure the axes parameters</source>
      <translation>Configurează parametrii axelor</translation>
    </message>
  </context>
  <context>
    <name>Plot_Grid</name>
    <message>
      <location filename="PlotGui.py" line="112"/>
      <source>Show/Hide grid</source>
      <translation>Afisare/Ascundere grila</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="115"/>
      <source>Show/Hide grid on selected plot</source>
      <translation>Afisare/Ascundere grila pe graficul selectat</translation>
    </message>
  </context>
  <context>
    <name>Plot_Labels</name>
    <message>
      <location filename="PlotGui.py" line="155"/>
      <source>Set labels</source>
      <translation>Seteaza etichete</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="158"/>
      <source>Set title and axes labels</source>
      <translation>Seteaza titlul si etichetele axelor</translation>
    </message>
  </context>
  <context>
    <name>Plot_Legend</name>
    <message>
      <location filename="PlotGui.py" line="138"/>
      <source>Show/Hide legend</source>
      <translation>Afisare/Ascundere legenda</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="141"/>
      <source>Show/Hide legend on selected plot</source>
      <translation>Afisare/Ascundere legenda in graficul selectat</translation>
    </message>
  </context>
  <context>
    <name>Plot_Positions</name>
    <message>
      <location filename="PlotGui.py" line="172"/>
      <source>Set positions and sizes</source>
      <translation>Seteaza poziţia si dimensiunile</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="175"/>
      <source>Set labels and legend positions and sizes</source>
      <translation>Definiți etichetele, poziția și dimensiunea legendei</translation>
    </message>
  </context>
  <context>
    <name>Plot_SaveFig</name>
    <message>
      <location filename="PlotGui.py" line="48"/>
      <source>Save plot</source>
      <translation>Salvați graficul</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="51"/>
      <source>Save the plot as an image file</source>
      <translation>Salvează graficul ca un fișier imagine</translation>
    </message>
  </context>
  <context>
    <name>Plot_Series</name>
    <message>
      <location filename="PlotGui.py" line="84"/>
      <source>Configure series</source>
      <translation>Configurarea seriilor</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="87"/>
      <source>Configure series drawing style and label</source>
      <translation>Configurarea stilului de desenare si etichetei pentru serii</translation>
    </message>
  </context>
  <context>
    <name>plot_axes</name>
    <message>
      <location filename="TaskPanel.py" line="180"/>
      <source>Configure axes</source>
      <translation>Configurare axe</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="184"/>
      <source>Active axes</source>
      <translation>Axe active</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="216"/>
      <source>Apply to all axes</source>
      <translation>Se aplica la toate axele</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="220"/>
      <source>Dimensions</source>
      <translation>Dimensiuni</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="224"/>
      <source>X axis position</source>
      <translation>Pozitia axei x</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="228"/>
      <source>Y axis position</source>
      <translation>Pozitia axei y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="204"/>
      <source>Scales</source>
      <translation>Scari</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="208"/>
      <source>X auto</source>
      <translation>X auto</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="212"/>
      <source>Y auto</source>
      <translation>Y auto</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="232"/>
      <source>Index of the active axes</source>
      <translation>Indicii axelor active</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="237"/>
      <source>Add new axes to the plot</source>
      <translation>Adauga axe noi la grafic</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="242"/>
      <source>Remove selected axes</source>
      <translation>Elimina axele selectate</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="247"/>
      <source>Check it to apply transformations to all axes</source>
      <translation>Bifati pentru a aplica transformarea tuturor axelor</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="252"/>
      <source>Left bound of axes</source>
      <translation>Marginea stanga a axelor</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="257"/>
      <source>Right bound of axes</source>
      <translation>Marginea dreapta a axelor</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="262"/>
      <source>Bottom bound of axes</source>
      <translation>Marginea de jos a axelor</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="267"/>
      <source>Top bound of axes</source>
      <translation>Marginea de sus a axelor</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="272"/>
      <source>Outward offset of X axis</source>
      <translation>Deplasare spre exterior pe axa x</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="277"/>
      <source>Outward offset of Y axis</source>
      <translation>Deplasare spre interior pe axa Y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="282"/>
      <source>X axis scale autoselection</source>
      <translation>Selecție automată pentru scara axei X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="287"/>
      <source>Y axis scale autoselection</source>
      <translation>Selecție automată pentru scara axei Y</translation>
    </message>
  </context>
  <context>
    <name>plot_console</name>
    <message>
      <location filename="Plot.py" line="47"/>
      <source>matplotlib not found, so Plot module can not be loaded</source>
      <translation>matplotlib nu a fost găsit, astfel că modulul Plot nu poate fi încărcat</translation>
    </message>
    <message>
      <location filename="InitGui.py" line="58"/>
      <source>matplotlib not found, Plot module will be disabled</source>
      <translation>matplotlib nu a fost găsit, astfel că modulul Plot va fi dezactivat</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="48"/>
      <source>Plot document must be selected in order to save it</source>
      <translation>Pentru a fi salvat, documentul Plot trebuie să fie selectat</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="346"/>
      <source>Axes 0 can not be deleted</source>
      <translation>Axele 0 nu pot fi sterse</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="101"/>
      <source>The grid must be activated on top of a plot document</source>
      <translation>Grila trebuie activată pe partea de sus a graficului unui document</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="129"/>
      <source>The legend must be activated on top of a plot document</source>
      <translation>Legenda trebuie activată pe partea de sus a graficului documentului</translation>
    </message>
  </context>
  <context>
    <name>plot_labels</name>
    <message>
      <location filename="TaskPanel.py" line="138"/>
      <source>Set labels</source>
      <translation>Seteaza etichete</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="142"/>
      <source>Active axes</source>
      <translation>Axe active</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="146"/>
      <source>Title</source>
      <translation>Titlu</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="150"/>
      <source>X label</source>
      <translation>eticheta X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="154"/>
      <source>Y label</source>
      <translation>eticheta Y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="158"/>
      <source>Index of the active axes</source>
      <translation>Indicii axelor active</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="163"/>
      <source>Title (associated to active axes)</source>
      <translation>Titlu (asociat cu axele active)</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="168"/>
      <source>Title font size</source>
      <translation>Dimensiunea font-ului pentru titlu</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="173"/>
      <source>X axis title</source>
      <translation>Titlu pentru axa X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="178"/>
      <source>X axis title font size</source>
      <translation>Dimensiunea font-ului pentru axa X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="183"/>
      <source>Y axis title</source>
      <translation>Titlu pentru axa Y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="188"/>
      <source>Y axis title font size</source>
      <translation>Dimensiunea font-ului pentru axa Y</translation>
    </message>
  </context>
  <context>
    <name>plot_positions</name>
    <message>
      <location filename="TaskPanel.py" line="124"/>
      <source>Set positions and sizes</source>
      <translation>Seteaza poziţia si dimensiunile</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="129"/>
      <source>Position</source>
      <translation type="unfinished">Position</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="134"/>
      <source>Size</source>
      <translation>Dimensiune</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="144"/>
      <source>X item position</source>
      <translation>Pozitia pe X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="149"/>
      <source>Y item position</source>
      <translation>Pozitia pe Y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="154"/>
      <source>Item size</source>
      <translation>Dimensiune element</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="139"/>
      <source>List of modifiable items</source>
      <translation>Lista obiectelor modificable</translation>
    </message>
  </context>
  <context>
    <name>plot_save</name>
    <message>
      <location filename="TaskPanel.py" line="132"/>
      <source>Save figure</source>
      <translation>Salveaza figura</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="137"/>
      <source>Inches</source>
      <translation>Țoli</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="142"/>
      <source>Dots per Inch</source>
      <translation>Puncte pe Țol</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="147"/>
      <source>Output image file path</source>
      <translation>Calea pentru fisierul imagine rezultat</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="152"/>
      <source>Show a file selection dialog</source>
      <translation>Prezinta dialogul de selectie a fisierelor</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="157"/>
      <source>X image size</source>
      <translation>Dimensiune imagine pe X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="162"/>
      <source>Y image size</source>
      <translation>Dimensiune imagine pe Y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="168"/>
      <source>Dots per point, with size will define output image resolution</source>
      <translation>Puncte pe pixel, cu care se vor defini rezoluția imaginii de ieșire</translation>
    </message>
  </context>
  <context>
    <name>plot_series</name>
    <message>
      <location filename="TaskPanel.py" line="157"/>
      <source>No label</source>
      <translation>Fara eticheta</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="192"/>
      <source>Line style</source>
      <translation>Stilul de linie</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="172"/>
      <source>Marker</source>
      <translation>Marcator</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="152"/>
      <source>Configure series</source>
      <translation>Configurarea seriilor</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="177"/>
      <source>List of available series</source>
      <translation>Lista seriilor disponibile</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="182"/>
      <source>Line title</source>
      <translation>Titlul liniei</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="197"/>
      <source>Marker style</source>
      <translation>Stil marcator</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="202"/>
      <source>Line width</source>
      <translation>Latimea liniei</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="207"/>
      <source>Marker size</source>
      <translation>Dimensiune marcator</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="212"/>
      <source>Line and marker color</source>
      <translation>Culoare linie si marker</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="162"/>
      <source>Remove series</source>
      <translation>Elimină seria</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="187"/>
      <source>If checked, series will not be considered for legend</source>
      <translation>Dacă e bifat, seria nu va fi luată în considerare pentru legendă</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="217"/>
      <source>Removes this series</source>
      <translation>Elimină această serie</translation>
    </message>
  </context>
</TS>
